"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheckPayments = void 0;
const baseResource_1 = require("./baseResource");
class CheckPayments extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/check-payments", config);
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async get(id, include) {
        return this.httpGetWithInclude(`/${id}`, include);
    }
    async return(request) {
        return this.httpPost(`/${request.id}/return`, { data: request.data });
    }
    async approve(request) {
        return this.httpPost(`/${request.id}/approve`, { data: request.data });
    }
    async getImage(id, front = true, responseEncoding = "binary", responseType = "blob") {
        const p = front ? "front" : "back";
        return this.httpGet(`/${id}/${p}`, { responseEncoding, responseType });
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.since) && { "filter[since]": params.since }),
            ...((params === null || params === void 0 ? void 0 : params.until) && { "filter[until]": params.until }),
            ...((params === null || params === void 0 ? void 0 : params.fromAmount) && { "filter[fromAmount]": params.fromAmount }),
            ...((params === null || params === void 0 ? void 0 : params.toAmount) && { "filter[toAmount]": params.toAmount }),
            ...((params === null || params === void 0 ? void 0 : params.checkNumber) && { "filter[checkNumber]": params.checkNumber }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "tags": params.tags }),
            ...((params === null || params === void 0 ? void 0 : params.sort) && { "sort": params.sort }),
            ...((params === null || params === void 0 ? void 0 : params.include) && { "sort": params.include })
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
}
exports.CheckPayments = CheckPayments;
