"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rewards = void 0;
const baseResource_1 = require("./baseResource");
class Rewards extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/rewards", config);
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    /**
     * Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account, transaction. See [Getting Related Resources](https://developers.unit.co/about-jsonapi/#intro-getting-related-resources)
     */
    async get(id, include) {
        const params = { ...(include && { include }) };
        return this.httpGet(`/${id}`, { params });
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.transactionId) && { "filter[transactionId]": params.transactionId }),
            ...((params === null || params === void 0 ? void 0 : params.rewardedTransactionId) && { "filter[rewardedTransactionId]": params.rewardedTransactionId }),
            ...((params === null || params === void 0 ? void 0 : params.receivingAccountId) && { "filter[receivingAccountId]": params.receivingAccountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.cardId) && { "filter[cardId]": params.cardId }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": params.tags }),
            ...((params === null || params === void 0 ? void 0 : params.since) && { "filter[since]": params.since }),
            ...((params === null || params === void 0 ? void 0 : params.until) && { "filter[until]": params.until }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt",
            "include": (params === null || params === void 0 ? void 0 : params.include) ? params.include : ""
        };
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        return this.httpGet("", { params: parameters });
    }
}
exports.Rewards = Rewards;
